"use strict";(self.webpackChunk_dagster_io_dagit_app=self.webpackChunk_dagster_io_dagit_app||[]).push([[499],{76583:function(n,e,t){t.r(e),t.d(e,{InstanceConfig:function(){return y},INSTANCE_CONFIG_QUERY:function(){return I}});var o,i,r=t(99500),s=t(922),a=(t(81452),t(73701)),c=t(3159),l=t(7838),d=t(32030),f=t(34595),u=t(31112),x=t(12745),h=t(24818),m=t(325),g=t(47678),p=t(78093),j=t(82348),v=t(25171),b=t(8851),w=t(32289),C=(0,s.vJ)(o||(o=(0,r.Z)(["\n  .react-codemirror2 .CodeMirror.cm-s-instance-config {\n    box-shadow: 0 1px 0 ",";\n    height: 100%;\n  }\n\n  .react-codemirror2 .CodeMirror.cm-s-instance-config {\n    .config-highlight {\n      background-color: ",";\n    }\n"])),l.w.KeylineGray,l.w.Yellow200),y=m.memo((function(){(0,p.Px)(),(0,j.j)("Configuration");var n=m.useContext(v.N).pageTitle,e=(0,a.a)(I,{notifyOnNetworkStatusChange:!0}),t=(0,g.C4)(e,g.dT),o=e.data,i=null===o||void 0===o?void 0:o.instance.info;return o?(0,w.jsxs)(w.Fragment,{children:[(0,w.jsx)(C,{}),(0,w.jsx)(u.m,{title:(0,w.jsx)(x.X6,{children:n}),tabs:(0,w.jsx)(b.Z,{tab:"config",refreshState:t})}),(0,w.jsx)(d.x,{padding:{vertical:16,horizontal:24},border:{side:"bottom",width:1,color:l.w.KeylineGray},children:(0,w.jsxs)(x.pm,{children:["Dagster version: ",(0,w.jsx)(x.EK,{style:{fontSize:"16px"},children:o.version})]})}),(0,w.jsx)(h.NU,{editorDidMount:function(n){var e=document.location.hash;if(e){var t=new RegExp("^".concat(e.slice(1),":")),o=n.getSearchCursor(t);o.findNext()&&(n.markText(o.from(),o.to(),{className:"config-highlight"}),n.scrollIntoView(o.from()))}},value:i||"",options:{lineNumbers:!0,mode:"yaml"},theme:["instance-config"]})]}):(0,w.jsx)(d.x,{padding:{vertical:64},children:(0,w.jsx)(f.$,{purpose:"section"})})}));e.default=y;var I=(0,c.Ps)(i||(i=(0,r.Z)(["\n  query InstanceConfigQuery {\n    version\n    instance {\n      id\n      info\n    }\n  }\n"])))},8851:function(n,e,t){t.d(e,{Z:function(){return v}});var o=t(32030),i=t(31269),r=t(325),s=t(47678),a=t(36819),c=t(7838),l=t(13243),d=t(81081),f=t(32289),u=r.memo((function(){var n=r.useContext(l.Z).daemons;return n?(0,f.jsx)(d.a,{content:n.content,position:"bottom",modifiers:{offset:{enabled:!0,options:{offset:[0,28]}}},children:(0,f.jsx)(a.JO,{name:"warning",color:c.w.Yellow500})}):null})),x=t(11831),h=t(34595),m=r.memo((function(n){var e=n.placeholder,t=r.useContext(l.Z).codeLocations;return t?"spinner"===t.type?(0,f.jsx)(x.u,{content:t.content,placement:"bottom",children:(0,f.jsx)(h.$,{purpose:"body-text",fillColor:c.w.Gray300})}):(0,f.jsx)(d.a,{content:t.content,position:"bottom",modifiers:{offset:{enabled:!0,options:{offset:[0,28]}}},children:(0,f.jsx)(a.JO,{name:"warning",color:c.w.Yellow500})}):e?(0,f.jsx)("div",{style:{width:"16px"}}):null})),g=t(37286),p=t(25171),j=t(40515),v=function(n){var e=n.refreshState,t=n.tab,a=r.useContext(p.N).healthTitle,c=(0,j._)();return(0,f.jsxs)(o.x,{flex:{direction:"row",justifyContent:"space-between",alignItems:"flex-end"},children:[(0,f.jsxs)(i.mQ,{selectedTabId:t,children:[(0,f.jsx)(g.f,{id:"locations",title:"Code locations",to:"/locations",icon:(0,f.jsx)(m,{placeholder:!1})}),(0,f.jsx)(g.f,{id:"health",title:a,to:"/health",icon:(0,f.jsx)(u,{})}),c?(0,f.jsx)(g.f,{id:"config",title:"Configuration",to:"/config"}):null]}),e?(0,f.jsx)(o.x,{padding:{bottom:8},children:(0,f.jsx)(s.xi,{refreshState:e})}):null]})}},40515:function(n,e,t){t.d(e,{_:function(){return a}});var o,i=t(99500),r=t(73701),s=t(3159),a=function(){var n=(0,r.a)(c).data;return!(null===n||void 0===n||!n.instance.hasInfo)},c=(0,s.Ps)(o||(o=(0,i.Z)(["\n  query InstanceConfigHasInfo {\n    instance {\n      id\n      hasInfo\n    }\n  }\n"])))},37286:function(n,e,t){t.d(e,{f:function(){return d}});var o=t(95764),i=t(81034),r=t(922),s=t(31269),a=(t(325),t(74549)),c=t(32289),l=["to","title","disabled"],d=(0,r.ZP)((function(n){var e=n.to,t=n.title,r=n.disabled,d=(0,i.Z)(n,l),f=(0,s.xv)(n),u=(0,s.BY)(n),x="string"===typeof t?t:void 0;return(0,c.jsx)(a.rU,(0,o.Z)((0,o.Z)((0,o.Z)({to:r?"#":e,title:x},f),d),{},{children:u}))})).withConfig({displayName:"TabLink",componentId:"sc-1rmmczd-0"})(["",""],s.gA)}}]);
//# sourceMappingURL=499.37926a62.chunk.js.map