"use strict";(self.webpackChunk_dagster_io_dagit_app=self.webpackChunk_dagster_io_dagit_app||[]).push([[594],{86594:function(e,t,n){n.r(t),n.d(t,{FallthroughRoot:function(){return x}});var r=n(32030),i=n(34595),o=n(7838),s=n(89646),a=n(75453),l=n(325),c=n(27601),d=n(39061),u=n(76336),p=n(25582),f=n(32289),x=function(){return(0,f.jsx)(c.rs,{children:(0,f.jsx)(c.AW,{path:"*",children:(0,f.jsx)(h,{})})})},g=function(e){return e.repository.pipelines.filter((function(e){return!(0,d.pv)(e.name)}))},h=function(){var e=l.useContext(u.C5),t=e.allRepos,n=e.loading,d=e.locationEntries;if(n)return(0,f.jsx)(r.x,{flex:{direction:"row",justifyContent:"center"},style:{paddingTop:"100px"},children:(0,f.jsxs)(r.x,{flex:{direction:"row",alignItems:"center",gap:16},children:[(0,f.jsx)(i.$,{purpose:"section"}),(0,f.jsx)("div",{style:{color:o.w.Gray600},children:"Loading definitions\u2026"})]})});if(d.length&&0===t.length)return(0,f.jsx)(c.l_,{to:"/locations"});var x=t.filter((function(e){return g(e).length>0}));if(0===x.length){var h=t.find((function(e){return e.repository.assetGroups.length}));if(h)return(0,f.jsx)(c.l_,{to:(0,p.rO)(h.repository.name,h.repositoryLocation.name,"/asset-groups/".concat(h.repository.assetGroups[0].groupName))})}if(1===x.length&&1===g(x[0]).length){var j=x[0],m=g(j)[0];return(0,f.jsx)(c.l_,{to:(0,p.jT)({repoName:j.repository.name,repoLocation:j.repositoryLocation.name,pipelineName:m.name,isJob:m.isJob})})}if(x.length>0)return(0,f.jsx)(c.l_,{to:"/overview"});var y=t[0];return(0,f.jsx)(r.x,{padding:{vertical:64},children:(0,f.jsx)(s.t,{icon:"no-results",title:y?"No jobs":"No definitions",description:y?"Your definitions are loaded, but no jobs were found.":"Add a job to get started.",action:(0,f.jsx)(a.fr,{href:"https://docs.dagster.io/getting-started",children:"View documentation"})})})};t.default=x},89646:function(e,t,n){n.d(t,{t:function(){return c}});n(325);var r=n(32030),i=n(7838),o=n(36819),s=n(34595),a=n(12745),l=n(32289),c=function(e){var t=e.title,n=e.description,c=e.icon,d=e.action,u=e.shrinkable,p=1===[t,n,d].filter(Boolean).length;return(0,l.jsxs)(r.x,{flex:{gap:20,alignItems:p?"center":"flex-start"},background:i.w.Gray50,padding:24,style:{margin:"auto",borderRadius:8,width:u?"initial":"max-content",maxWidth:500},children:["spinner"===c?(0,l.jsx)(s.$,{purpose:"section"}):"no-results"===c?(0,l.jsx)(o.JO,{name:"search",size:48,color:i.w.Gray400}):(0,l.jsx)(o.JO,{name:c,size:48,color:i.w.Gray400}),(0,l.jsxs)(r.x,{flex:{gap:8,direction:"column",alignItems:"flex-start"},children:[t&&(0,l.jsx)(a.pm,{style:{color:i.w.Gray900},children:t}),n&&(0,l.jsx)("div",{style:{color:i.w.Gray500},children:n}),d]})]})}}}]);
//# sourceMappingURL=594.970720e7.chunk.js.map